Monday, May 28, 2012

How to find objects present more than twice on the project tree (Synergy tip work)

There is a bug in Synergy 7.1* running on Linux server (PM29256, http://www-304.ibm.com/support/docview.wss?uid=swg1PM29256).
If the same object is present twice in different directories the Sync fails with the  “Warning: Error in Executing SVM request” or crashes altogether.
According to IBM it has been fixed in 7.2.

In the meanwhile the workaround is to replace the object with the soft link to it in all the occasions but the one. This will work for the projects being developed in Linux environment.

To find out the “duplicated” objects:

1.      ccm query "is_member_of(‘4 part project identifier’)" -u -f %objectname > project_members.list
2.      for obj in `cat project_members.list `;do echo $obj >> duplicates; ccm query "has_child('$obj','projectname#version')" >> dupl_dirs;done
3.      grep -B2 ^2\) dupl_dirs

Where the project details are needed use the project in questionJ.


This will yield the list of the objects that appear on the tree twice. E.g.

myfile.h#ver2:incl:1
1) base #ver12 integrate david dir YYY 2  85654
2) http#ver32  integrate david dir YYY 17 21471
--
abc#ver4:script:1
1) foo#ver.3 released abby dir YYY 1  29349
2) bar#ver.2 released abby dir YYY 31 22563

End of story.

Sunday, May 20, 2012

Useful task attributes

Useful task attributes are: %name, %displayname, %objectname, %task_number.
Example:
%displayname=12345
%name=task12345
%objectname=task12345#1:task:probtrac
%task_number=12345

Have "make" report all the commands run as it goes

export QUIET_MAKE=" "


Environment variable QUIET_MAKE will cause make print all the executed commands to STDOUT.
Set it to space: " ".

Press "Ctrl" key while starting Java client to get a debug window

Will see the path searched, log files locations, LAX version, where the preferences are read from etc.

How to find the original process that owns / created the locks as shown by "ccm monitor -showlocks" (Synergy work tip)

Step 1:  show locks

Ø  ccm monitor -showlocks

Locked objects --
/data/synergydb//db+1306154
       ---> myserver:58903:132.106.241.41


Step 2:  find the sessions, including session owner

Ø  ccm ps -engine_address myserver:58903:132.106.241.41

Processes with engine_address = myserver:58903: 132.106.241.41, ...
1 processes located:
----------------------
rfc address (moses.corp.something.com:46106:10.140.2.182)
        process (cmd_interface)
        callback (ciserver:cb_init)
        display ()
        display_name (Classic Command Interface)
        pid (21295)
        user (mybuild)
        host (moses.corp.something.com)
        host_addr ()
        msg_handler_1 (uissys:message_handler)
        database (/data/synergydb//db)
        engine_address (myserver:58903:132.106.241.41)


How to set up the security read restrictions to all the members of specific project that belong to original component but not to other known components

  •  ccm set role group_mgr
  • ccm query -i group (this bring us the grop name)
  •  ccm query "is_member_of('PROJNAME#<proj ver>') and type !='dir' and is_associated_object_of(cvtype='task' and release match '*') and not is_associated_object_of(cvtype='task' and release match 'COMP1*' or release match 'COMP2*' or release match 'COMP3*')" -u -f "%objectname %task_release %task" > compname_only.list
  • ccm groups -a -v :readsource @ (this actually adds the group attribute with a read restriction)
  • ccm set rile developer



E

Synergy conflilcts: "parallel, not included"

Conflicts report a lot of files, all belong to a single task, the task
is for release that is not in process rules (reconfigure properties).

Here is how to find:

1. List all the objects of the offending task (35742):
> ccm task -show objects  35742  -u -f %objectname >  35742 .obj

2. Query for all the immediate successors of the task objects:
> for obj in `cat  35742 .obj`;do ccm query "has_predecessor('$obj')" -f
"%objectname %task_release" >> successors;done

3. Grep the list for objects of your current release:
> grep 27.0.3.20 successors

2) trroute.c#KUKU_27.0.3.20.1:csrc:3 KUKU_27.0.3.20

End of story.

ccm ps -host gives you the command currently running on a specific database!

> ccm ps –host myhost


rfc address (myhost:36996:131.120.211.116)
        process (engine)
        callback (engine_startup:cb_init)
        platform (unix)
        pid (15767)
        user (mybuild)
        host (myhost)
        host_addr ()
        ui_address (client.corp.company.com:53851:10.213.1.130)
        database (/data/synergydb/mydb/db)
        reconfigure (1/project/KU110/Appl_1.11.08DL_B,1/project/KU110/Appl_1.11.08DL_B)

Set up Synergy Linux client to use non-default merge tool (work tip Synergy merge compare)

To customize merge and compare utilities for Synergy Java client running on Linux:

1. Exit java client.

2. Assuming you use BeyondCompare as a merge and compare tool, and it is installed as /usr/bin/bcompare

 Add into ~/.ccm.user.properties file the following lines:

  unix.tool.merge.ascii=/usr/bin/bcompare %file1 %file2 -mergeoutput\=%outfile
  unix.tool.compare.ascii=/usr/bin/bcompare %file1 %file2

Changes will have an effect when Synergy starts next time.

Tuesday, May 24, 2011

Synergy error 'Cannot lock project' upon reconfigure (update)

Somehow this page disappeared from IBM site so replicating it here. Historical number below hints that it was created during Telelogic days.

Message 'Cannot lock project' while doing a reconfigure or reconcile

Technote (FAQ)

Question

I am getting the message 'Cannot lock project' while doing a reconfigure or reconcile. How can I resolve this?

Answer

When you initiate an operation which modifies the project members, such as reconfigure, the projectis locked. If the operation terminates abnormally, the lock may not be cleaned up and subsequent actions may fail and result in a 'Cannot lock project' message. For example, if a user terminated their client during a large reconfigure, rather than waiting for the operation to finish.

If all actions took place using the same client, restart the client and this will usually resolve the issue. This is normally the case for a working project.

If however multiple clients are accessing the project it may be more difficult to resolve the issue. This may be the case for prep and shared projects.

The solution for this should be to run:

ccm monitor -showlocks

ccm monitor -removelock XXX


...where XXX is the full line returned from showlocks.

If this still does not resolve the situation, then you will need to shutdown the entire database with the 'ccmdb shutdown' command, to ensure all connections are terminated.

Should the problem persist even after a 'ccmdb shutdown' then you should run:

onstat -k > locks.txt


and contact IBM Rational Client Support for further assistance and specific steps for your environment.

Once the onstat command has been performed then you can also restart Informix, as this should release the locks effecting the operation.

Historical Number

KB7898

Synergy groups: setting up read-only access to sources of specific project that come from specific releases only

Assume a role of group_mgr:

$ ccm set role group_mgr

Note: if you do not have a group_mgr role assume the role of ccm_admin and add yourself the group_mgr role. End the session and start over.

Verify:

$ ccm set role

group_mgr

Create group:

$ ccm groups -c mygroup

This will open the vi (or any other text editor you have set as a default) session where you should write all the names of the users to be members of the group, in a single line, space-delimited.

Once you are done adding the users save the file and close editor session. The group will be created.

Do not bother sorting the names, next time you look at it via ccm groups -show mygroup you will see all the names sorted alphabetically. And they will be cut in several lines anyway.

List groups:

$ ccm query -i group

1) group/admin/mygroup/1 admin myuser admin <void> group <void>

List group attribute: (so we know what can be viewed or changed):

$ ccm attr -l @1

create_time (time) (local)

cvtype (string) (local)

is_asm (boolean) (local)

is_model (boolean) (local)

membership (text) (local)

modify_time (time) (local)

name (string) (local)

owner (string) (local)

status (string) (local)

subsystem (string) (local)

version (string) (local)

View group owner:

$ ccm attr -s owner @1

myuser

View group members:

$ ccm attr -s membership @1

OR

$ ccm groups -show mygroup

Change group membership:

$ ccm groups -e <group name>

e.g. ccm groups –e mygroup

Query for all the objects to assign to the group (all objects in the ABC_v721_00 project that belong to the ABC* releases):

$ ccm query "is_member_of('ABCAPP#V721_00') and is_associated_object_of(cvtype='task' and release match 'ABC*') and type !='dir'"

Assign ABCAPP#V721_00 721-only objects to the dp security group with read-deny access to others:

$ ccm groups -a -v mygroup:readsource @

Monday, September 27, 2010

Synergy issue with object access restriction

Background
Synergy provides for setting both read and write restrictions on all kinds of objects (projects, files, directories).
When the restrictions are applied only the members of the specific predefined security group are able to read or read and modify objects as appropriate.
If you get the "write restrictions" error during check out, you are probably not a member of the security group that owns an object.
Security restrictions are applied hierarchically top down, from the project level down to the individual files.
Access mode to the object can only be changed while the object is in the modifiable state (e.g. "working").
When the security restrictions are lifted from the project, non-modifiable members of it (files and directories) are still left with the original restrictions applied. Even when the objects subsequently become members of other projects, restrictions on objects are retained.
More on the subject is in the original vendor docs.
What to do?
Find out what group the object belongs to (GUI, Object Properties -> Security).
Find out the group owner (CLI, first user that appears in the list of group members).
Call the group owner to see if you should be added to this group to gain an access to the object.
If you create a new project version and wish to lift all the inherited access restrictions that may exist on your project objects, call CM admin to do the job.
(The ugly solution is to have the original group member or admin Check Out all the project members and change the security settings on the checked out versions without making any other modification to the objects. Then Check In all the objects back.)

Monday, August 9, 2010

Synergy Classic client GUI troubles

Trouble: classic client running on Linux RH 5 machine behaves oddly:

- right-click does not work,
- no way to select more than one item at at time (several files in the tree view, or two versions on history view),
- mouse single click responding as a double-click should,
- backspace character typing garbage,
- strange fonts ...

What helps:

1. Make sure NumLock key is disabled. Vendor also suggest checking the CapsLock key.

2. Synergy Classic client GUI is governed by the number of setup files, that define fonts, colors and other application GUI qualities.
Original "CM Synergy - X Resource File" file Ccm is located in $CCM_HOME/etc contains the most of the setting. Upon machine setup this file has to be copied to the local X directory:
root# cp $CCM_HOME/etc/Ccm /usr/lib/X11/app-defaults

If you do not have root over the Linux machine try to copy the Ccm file into your home directory:
user# cp $CCM_HOME/etc/Ccm ~/

Also,
(found on vendor site)

If during ccm start, messages about undefined X attributes are displayed ...


If errors indicating undefined X attribtues are seen duing a Synergy session startp, it is possible the Ccm X app-defaults file isn't being found or was incorrectly installed, or there may be an incompatibility with the user's environment settings (i.e., XAPPLRESDIR, XFILESEARCHPATH or XUSERFILESEARCHPATH may be set).

This issue also can typically be resolved by copying the Ccm file from $CCM_HOME/etc to the user's $HOME directory. If the user is using XAPPLRESDIR, XFILESEARCHPATH or XUSERFILESEARCHPATH, add the location of the Ccm file to one of those paths. Stop and restart the CCM session to validate the solution.

Tuesday, June 29, 2010

Check Out failed. Message "Operation failed because it requires both read and write privileges"

The files with the problem reported originated from the project that had some security access restrictions set.

Some time ago these security restrictions were lifted on all the projects, but the files that became members of the derived (subsequent) projects retained these restrictions.
If these restrictions are no longer relevant - ask an admin or a member of original security group to remove them, by checking out files and changing the security on each file individually,
if they still are - see if you should be the member of the group that does have the write access to these files.

To remove files access restrictions:
- create a task and check out the file(s),
- right click the file object,
- select Properties -> Security.
- see the groups managing the object,
-
remove the check mark by the group name or check the appropriate radio button to remove the restrictions altogether,
- complete task.

"ACcent execution aborted in module ..."

There are several reasons for failures reported as "ACcent execution aborted in module".
Some are described and detailed in IBM Tech notes (like the DCM related here), others are said to be caused by the inconsistency in the server and client versions.

What I found yesterday was the location of the local copy of the database files that can be passed to the ccm start command with the "-u" flag.

At first we had these lines reported as a warning upon session start. They say in this situation session would start and we saw some operations performed, but some would fail, so it is not safe to ignore these:

ACcent execution aborted in module attr:10028, file /tmp/acAAEFBD.TMP.ac, line 14
ACcent execution aborted in module modinit, file src/base/model_init.ac, line 63
ACcent execution aborted in module remote_client, file src/base/remote_client.ac, line 59
ACcent execution aborted in module remote_client, file src/base/remote_client.ac, line 42
ACcent execution aborted in module base, file src/base/base.ac, line 401
ACcent execution aborted in module base, file src/base/base.ac, line 275
Warning: operand of generic cast has an incompatible type
Starting in multiple server mode.
Set the environment variable CCM_ADDR to machine:PID:IP to send commands to this server.


Then we zerroed out all the user ini files (.ccm.ini, ccm.properties etc.) and started afresh.
Now even the status command failed:

> ccm status
Warning: ACcent execution aborted in 'lscmds:status'
ACcent execution aborted in module lscmds, file src/foci/lscmds.ac, line 136
ACcent execution aborted in module base, file src/base/base.ac, line 401
ACcent execution aborted in module base, file src/base/base.ac, line 325
Warning: Lost connection to engine, exiting
Warning: Command execution failed.
Check user interface log file for error messages.

This helped at the end:
ccm start -d -h -m -nogui -u /tmp/whateverlocation -rc

Thursday, June 10, 2010

Synergy: release attributes

Just in case, here are the release attributes (and how to list them)

> ccm query -type releasedef -name "KUKU"
...
> ccm attr -la @1
_import_status_order (string) (inherited)
active (boolean) (local)
allow_dcm_transfer (boolean) (local)
allow_delimiter_in_name (boolean) (inherited)
allow_delimiter_in_version (boolean) (inherited)
atcp_attrs (text) (inherited)
auto_merge_cmd (string) (inherited)
baseline (string) (local)
can_be_product (boolean) (inherited)
cli_compare_cmd (string) (inherited)
cli_merge_cmd (string) (inherited)
component_name (string) (local)
component_release (string) (local)
create (acc_method) (inherited)
create_time (time) (local)
cvtype (string) (local)
dcm_has_modifiable_in (boolean) (inherited)
dcm_non_specific_instance (boolean) (inherited)
delete (acc_method) (inherited)
derive (acc_method) (inherited)
description (text) (local)
dflt_status (string) (inherited)
diff_source_attr (string) (inherited)
displayname (acc_method) (inherited)
export_exclude_attrs (text) (inherited)
export_exclude_relations (text) (inherited)
groups (text) (local)
gui_compare_cmd (string) (inherited)
gui_merge_cmd (string) (inherited)
icon (string) (inherited)
import_ignore_attrs (text) (inherited)
included_releases (text) (local)
is_asm (boolean) (local)
is_model (boolean) (local)
is_versioned (boolean) (inherited)
keyword_expand_attrs (text) (inherited)
manager (string) (local)
max_component_name_length (string) (inherited)
max_component_release_length (string) (inherited)
modify_time (time) (local)
name (string) (local)
next_version (acc_method) (inherited)
no_copy_on_derive (text) (inherited)
objectname (acc_method) (inherited)
owner (string) (local)
parallel_check_in (boolean) (local)
parallel_check_out (boolean) (local)
parallel_create (boolean) (inherited)
parallel_promote (boolean) (inherited)
parallel_promote_defs (text) (inherited)
parallel_promote_states (string) (inherited)
phase (text) (local)
phase_log (text) (local)
post_create (acc_method) (inherited)
post_derive (acc_method) (inherited)
post_set_status (acc_method) (inherited)
pre_create (acc_method) (inherited)
pre_derive (acc_method) (inherited)
pre_set_status (acc_method) (inherited)
relate (acc_method) (inherited)
require_task (string) (inherited)
restricted_attributes (text) (inherited)
set_status (acc_method) (inherited)
source_attrs (text) (inherited)
source_diff (acc_method) (inherited)
source_merge (acc_method) (inherited)
status (string) (local)
status_log (uptext) (local)
subsystem (string) (local)
super_type (string) (inherited)
type_description (string) (inherited)
ui_defs (acc_method) (inherited)
unrelate (acc_method) (inherited)
version (string) (local)
version_delims (text) (inherited)
version_diff (acc_method) (inherited)
wa_type (string) (inherited)
xml_export_exclude_attrs (text) (inherited)
xml_export_exclude_relations (text) (inherited)
xml_import_ignore_attrs (text) (inherited)
xml_import_noimage_attrs (text) (inherited)

Monday, May 31, 2010

Check Outs into a project with no work area

Did yo know that files been Checked Out into a project with no work area will disappear from this project on the next Update operation?
The objects will remain in the database, and when Checked In will be found in the project.
So if you ever need to Check Out an object from the project with no work area make sure to Check them In before making further changes.

Tuesday, April 13, 2010

Synergy Linux Java client failed to start

Symptoms:
Both CLI and Classic client start fine, but the Java client start fails. It displays the login dialog, then briefly displays splash screen, then fails with no message.
The only trace is the ‘Permission denied’ in the ccm_eng.log.
Background:
The client IP has changed since the last good start.
Solution:
Make sure the server's /etc/hosts lists the correct machine name and IP for the client machine.
End of story.

Sunday, April 11, 2010

Error starting Java client on Linux machine

Symptoms:
The Linux Java client would not start with the following popup:






The log file $HOME/ccm_client.log has the following trace:
04/12 08:31:05 java.lang.IllegalArgumentException: Width (0) and height (0) cannot be <= 0
04/12 08:31:05 at java.awt.image.DirectColorModel.createCompatibleWritableRaster(DirectColorModel.java:999)
04/12 08:31:05 at sun.awt.X11.XFramePeer.setIconImage(XFramePeer.java:217)
04/12 08:31:05 at sun.awt.X11.XFramePeer.postInit(XFramePeer.java:75)
04/12 08:31:05 at sun.awt.X11.XBaseWindow.init(XBaseWindow.java:117)
04/12 08:31:05 at sun.awt.X11.XBaseWindow.<init>(XBaseWindow.java:150)
04/12 08:31:05 at sun.awt.X11.XWindow.<init>(XWindow.java:86)
04/12 08:31:05 at sun.awt.X11.XComponentPeer.<init>(XComponentPeer.java:101)
04/12 08:31:05 at sun.awt.X11.XCanvasPeer.<init>(XCanvasPeer.java:22)
04/12 08:31:05 at sun.awt.X11.XPanelPeer.<init>(XPanelPeer.java:27)
04/12 08:31:05 at sun.awt.X11.XWindowPeer.<init>(XWindowPeer.java:53)
04/12 08:31:05 at sun.awt.X11.XDecoratedPeer.<init>(XDecoratedPeer.java:36)
04/12 08:31:05 at sun.awt.X11.XFramePeer.<init>(XFramePeer.java:41)
04/12 08:31:05 at sun.awt.X11.XToolkit.createFrame(XToolkit.java:349)
04/12 08:31:05 at java.awt.Frame.addNotify(Frame.java:491)
04/12 08:31:05 at java.awt.Window.pack(Window.java:484)
04/12 08:31:05 at com.telelogic.cm.ccm_client.panes.LoginPane.showInFrame(LoginPane.java:473)
04/12 08:31:05 at com.telelogic.cm.ccm_client.StartClient.runClient(StartClient.java:654)
04/12 08:31:05 at com.telelogic.cm.ccm_client.StartClient.main(StartClient.java:95)
04/12 08:31:05 at sun.reflect.NativeMethodAccessorImpl.invoke0(Native Method)
04/12 08:31:05 at sun.reflect.NativeMethodAccessorImpl.invoke(NativeMethodAccessorImpl.java:39)
04/12 08:31:05 at sun.reflect.DelegatingMethodAccessorImpl.invoke(DelegatingMethodAccessorImpl.java:25)
04/12 08:31:05 at java.lang.reflect.Method.invoke(Method.java:585)
04/12 08:31:05 at com.zerog.lax.LAX.a([DashoPro-V1.2-120198])
04/12 08:31:05 at com.zerog.lax.LAX.main([DashoPro-V1.2-120198])
04/12 08:31:05 --- BEGIN UNHANDLED EXCEPTION ERROR REPORT ---
04/12 08:31:05 An internal error has occurred at Mon Apr 12 08:31:05 IDT 2010
04/12 08:31:05 Unhandled runtime exception: java.lang.IllegalArgumentException
04/12 08:31:05 Exception Message: Width (0) and height (0) cannot be <= 0
04/12 08:31:05
04/12 08:31:05 Stack trace:
04/12 08:31:05 java.lang.IllegalArgumentException: Width (0) and height (0) cannot be <= 0
04/12 08:31:05 at java.awt.image.DirectColorModel.createCompatibleWritableRaster(DirectColorModel.java:999)
:
04/12 08:31:05 at sun.awt.X11.XFramePeer.setIconImage(XFramePeer.java:217)
04/12 08:31:05 at sun.awt.X11.XFramePeer.postInit(XFramePeer.java:75)
04/12 08:31:05 at sun.awt.X11.XBaseWindow.init(XBaseWindow.java:117)
04/12 08:31:05 at sun.awt.X11.XBaseWindow.<init>(XBaseWindow.java:150)
04/12 08:31:05 at sun.awt.X11.XWindow.<init>(XWindow.java:86)
04/12 08:31:05 at sun.awt.X11.XComponentPeer.<init>(XComponentPeer.java:101)
04/12 08:31:05 at sun.awt.X11.XCanvasPeer.<init>(XCanvasPeer.java:22)
04/12 08:31:05 at sun.awt.X11.XPanelPeer.<init>(XPanelPeer.java:27)
04/12 08:31:05 at sun.awt.X11.XWindowPeer.<init>(XWindowPeer.java:53)
04/12 08:31:05 at sun.awt.X11.XDecoratedPeer.<init>(XDecoratedPeer.java:36)
04/12 08:31:05 at sun.awt.X11.XFramePeer.<init>(XFramePeer.java:41)
04/12 08:31:05 at sun.awt.X11.XToolkit.createFrame(XToolkit.java:349)
04/12 08:31:05 at java.awt.Frame.addNotify(Frame.java:491)
04/12 08:31:05 at java.awt.Window.pack(Window.java:484)
04/12 08:31:05 at com.telelogic.cm.ccm_client.panes.LoginPane.showInFrame(LoginPane.java:473)
04/12 08:31:05 at com.telelogic.cm.ccm_client.StartClient.runClient(StartClient.java:654)
04/12 08:31:05 at com.telelogic.cm.ccm_client.StartClient.main(StartClient.java:95)
04/12 08:31:05 at sun.reflect.NativeMethodAccessorImpl.invoke0(Native Method)
04/12 08:31:05 at sun.reflect.NativeMethodAccessorImpl.invoke(NativeMethodAccessorImpl.java:39)
04/12 08:31:05 at sun.reflect.DelegatingMethodAccessorImpl.invoke(DelegatingMethodAccessorImpl.java:25)
04/12 08:31:05 at java.lang.reflect.Method.invoke(Method.java:585)
04/12 08:31:05 at com.zerog.lax.LAX.a([DashoPro-V1.2-120198])
04/12 08:31:05 at com.zerog.lax.LAX.main([DashoPro-V1.2-120198])
04/12 08:31:05
04/12 08:31:05 Public SCCS_IDs:
04/12 08:31:05 @(#) %full_filespec: LoginPane.java,79:java:J#1 %
04/12 08:31:05 @(#) %full_filespec: StartClient.java,51.1.1:java:J#1 %
04/12 08:31:05
04/12 08:31:05 Release 6.5 4105
04/12 08:31:05 Build numbers:
04/12 08:31:05 com/telelogic/cm/internal/objectapi/ unknown
04/12 08:31:05 com/telelogic/cm/sessionmgr/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/command/ unknown
04/12 08:31:05 com/telelogic/cm/activecm/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/helper/ unknown
04/12 08:31:05 com/telelogic/cm/service/ 1998
04/12 08:31:05 com/telelogic/cm/objectapi/make/command/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/query/ unknown
04/12 08:31:05 com/telelogic/cm/shared_client/ 2003
04/12 08:31:05 com/telelogic/cm/eventservices/ 2011
04/12 08:31:05 com/telelogic/cm/objectapi/ unknown
04/12 08:31:05 com/telelogic/cm/common/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/error/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/query/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/make/ unknown
04/12 08:31:05 com/telelogic/cm/jrfc/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/accutil/ unknown
04/12 08:31:05 com/telelogic/cm/crapi/ unknown
04/12 08:31:05 com/telelogic/cm/licensemgr/ 1998
04/12 08:31:05 com/telelogic/cm/jrfc/router/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/access/ unknown
04/12 08:31:05 com/telelogic/cm/util/ unknown
04/12 08:31:05 com/telelogic/cm/crapi/adapters/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/service/ unknown
04/12 08:31:05 com/telelogic/cm/internal/users/ unknown
04/12 08:31:05 com/telelogic/cm/shared_client/acm/ 2003
04/12 08:31:05 com/telelogic/license/ 1998
04/12 08:31:05 com/telelogic/cm/internal/crapi/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/update/ unknown
04/12 08:31:05 com/telelogic/cm/server/ 1998
04/12 08:31:05 com/telelogic/cm/resource/ unknown
04/12 08:31:05 com/telelogic/cm/jrfc/objreg/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/dbconfig/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/workarea/ unknown
04/12 08:31:05 com/telelogic/cm/jrfc/activecm/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/command/ unknown
04/12 08:31:05 com/telelogic/cm/jrfc/utils/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/exception/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/adapters/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/security/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/helper/ unknown
04/12 08:31:05 com/telelogic/cm/util/event/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/longcall/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/update/command/ unknown
04/12 08:31:05 com/telelogic/cm/objectapi/database/ unknown
04/12 08:31:05 com/telelogic/cm/shared_client/util/ 2003
04/12 08:31:05 com/telelogic/cm/objectapi/dcm/ unknown
04/12 08:31:05 com/telelogic/cm/jrfc/types/ unknown
04/12 08:31:05 com/telelogic/cm/ccm_client/ unknown
04/12 08:31:05 com/telelogic/cm/internal/security/ unknown
04/12 08:31:05 com/telelogic/cm/internal/objectapi/warning/ unknown
04/12 08:31:05 --- END UNHANDLED EXCEPTION ERROR REPORT ---

Solution:
Set environment variable AWT_TOOLKIT:
export AWT_TOOLKIT=MToolkit

Explanation:

Synergy how to copy a project with subprojects

ccm checkout -wa -cb -project ProjName#proj_ver -update -subprojects -versions "firtsprojver:firtprojver_user,nextprojver:nextprojver_user" -path /home/user/ccm_wa